#! /bin/sh

./wasmsign2 keygen -k secret.key -K public.key

./wasmsign2 keygen -k secret.key2 -K public.key2

./wasmsign2 split -i z.wasm -o z2.wasm -s sdfsdf

echo -----

./wasmsign2 -v show -i z2.wasm

./wasmsign2 sign -k secret.key -i z2.wasm -o z3.wasm

./wasmsign2 verify -i z3.wasm -K public.key

./wasmsign2 split -i z2.wasm -o z3.wasm -s name

./wasmsign2 sign -k secret.key2 -K public.key2 -i z3.wasm -o z4.wasm

./wasmsign2 verify -i z4.wasm -K public.key && error "should fail"
./wasmsign2 verify -i z4.wasm -K public.key2
./wasmsign2 verify -i z4.wasm -K public.key2 -s 'name'
./wasmsign2 verify -i z4.wasm -K public.key2 -s 'debug|name'
